/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabian 'x3n' Landau
 *   Co-authors:
 *      ...
 *
 */

#ifndef _AsteroidMinable_H__
#define _AsteroidMinable_H__

#include "OrxonoxPrereqs.h"

#include <string>
#include <vector>
#include "interfaces/PickupCarrier.h"
#include "interfaces/RadarViewable.h"
#include "worldentities/ControllableEntity.h"
#include "worldentities/ExplosionPart.h"

#include "../../orxonox/worldentities/pawns/Pawn.h"

namespace orxonox // tolua_export
{


    // tolua_export
    class _OrxonoxExport AsteroidMinable : public Pawn
    { // tolua_export

        public:
            AsteroidMinable(Context* context);// This constructor is for XML access only!
            AsteroidMinable(Context* c, float size, Vector3 position);// Call this Constructor from other C-files.

            virtual ~AsteroidMinable();
            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode);
            virtual void XMLEventPort(Element& xmlelement, XMLPort::Mode mode) override;
            virtual void tick(float dt) override;

            // Overwrite to prevet 'self-collision' of generated stuff
            virtual void hit(Pawn* originator, const Vector3& force, const btCollisionShape* cs, float damage, float healthdamage = 0.0f, float shielddamage = 0.0f);
            virtual void hit(Pawn* originator, btManifoldPoint& contactpoint, const btCollisionShape* cs, float damage, float healthdamage = 0.0f, float shielddamage = 0.0f);



            virtual void setSize(float f);
            virtual float getSize();

            virtual void toggleShattering(bool b);





        protected:
            // Da neue Argumente reinstellen
            //float asteroidVersion; // Bodenstrich-Konvention?, 
            // Wert zwischen 1 und 6 (Spezialdinger?), die Mesh-Form
            float size;
            bool generateSmaller;
            bool initialised;

            Context* context;

            virtual void death(); 
            virtual void putStuff();



        private:
            void registerVariables();
            virtual void spawnChildren();

            void printArrayString(float thingy[]);// Just for testing
            void printArrayString(int thingy[]);// Just for testing





    }; // tolua_export
} // tolua_export

#endif /* _AsteroidMinable_H__ */
